/*
 * This file is part of StreetTraffic, which is an AI for OpenTTD
 * Copyright (C) 2009  Frank Jüdes with parts written by Leif Linse
 * 
 * Updated 25.10.2009 / v2 / bu
 *
 * OpenTTD Forum Link: http://www.tt-forums.net/viewtopic.php?f=65&t=42393
 *
 * Line 66: num_cars_total
 * Reduced maximum number of vehicles from 100000 to 50000 per AI player, if you need more, suggest to add another AI player
 *
 * Line 67: num_cars_per_town
 * New ratio 1 : 1000 instead of 1 : 100, result of car per inhabitant is more accurate and lower settings will prevent the cities from 
 * early traffic congestion. New values for easy (old value 1), medium (old value 2) and hard (old value 3) to fit to the new ratio.
 * 
 * Ingame days and their equivalent in AI ticks
 * Info: 1000 AI ticks are approx 54 ingame days, so one ingame day is approx 18 ticks, one week is approx 126, one month approx 504 ticks.
 * It is more convenient for the user to work here with days iso ticks, therefore the display has been changed now from ticks to ingame days.
 *
 * If you use the daylength patch, the ingame days will be affected by the daylength setting (e.g. setting "2" will reduce the ingame days by 50%)
 * Line 74 : daylength_ticks added to adjust the ticks per ingame day
 *
 * Line 71 : car_sleep_time 
 * Amended from easy_value = 40, medium_value = 20, hard_value = 10, custom_value = 20, min_value = 1, max_value = 300
 * to easy_value = 7, medium_value = 4, hard_value = 1, custom_value = 7, min_value = 1, max_value = 720
 *
 * Line 72 : town_sleep_time
 * Amended from easy_value = 200, medium_value = 100, hard_value = 50, custom_value = 200, min_value = 10, max_value = 3000
 * to easy_value = 30, medium_value = 14, hard_value = 7, custom_value = 30, min_value = 10, max_value = 720
 * 
 * Line 73 : eol_sleep_time
 * Amended from easy_value = 600, medium_value = 450, hard_value = 300, custom_value = 600, min_value = 10, max_value = 3000
 * to easy_value = 1800, medium_value = 900, hard_value = 360, custom_value = 900, min_value = 10, max_value = 1800
 * 
 * StreetTraffic is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License
 *
 * StreetTraffic is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with StreetTraffic; If not, see <http://www.gnu.org/licenses/> or
 * write to the Free Software Foundation, Inc., 51 Franklin Street, 
 * Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */

// min OpenTTD nightly: 2009-10-22 / tested on R17838 with daylength patch

class StreetTraffic2 extends AIInfo {
  function GetAuthor()      { return "Zuu, modified by fjuedes, updated by Tim"; }
  function GetName()        { return "StreetTraffic v2"; }
  function GetShortName()   { return "STV2"; }
  function GetDescription() { return "Builds random cars on your streets if you have a GRF with cars."; }
  function GetVersion()     { return 2; }
  function GetDate()        { return "2009-10-25"; }
  function CreateInstance() { return "StreetTraffic2"; }
	
  // There is no saved state, but by setting <= this version, users
  // will not use an older version that might not handle the vehicles
  // as good as the one that was used to make the save game
  function CanLoadFromVersion(version) { return version <= GetVersion(); }

  function GetSettings() {
    AddSetting({name = "num_towns_max", description = "Maximum number of towns where cars will be build", easy_value = 10, medium_value = 20, hard_value = 50, custom_value = 25, flags = 0, min_value = 1, max_value = 500});
    AddSetting({name = "num_cars_total", description = "Maximum total number of cars to build", easy_value = 500, medium_value = 500, hard_value = 500, custom_value = 500, flags = 0, min_value = 1, max_value = 50000});
    AddSetting({name = "num_cars_per_town", description = "Number of cars per 1000 inhabitants per town", easy_value = 2, medium_value = 5, hard_value = 10, custom_value = 2, flags = 0, min_value = 1, max_value = 250});
    AddSetting({name = "car_sleep_time", description = "Days to sleep after creating a single car", easy_value = 7, medium_value = 4, hard_value = 1, custom_value = 7, flags = 0, min_value = 1, max_value = 730});
    AddSetting({name = "town_sleep_time", description = "Days to sleep after creating cars in one town", easy_value = 30, medium_value = 14, hard_value = 7, custom_value = 30, flags = 0, min_value = 10, max_value = 730});
    AddSetting({name = "eol_sleep_time", description = "Days to sleep after finishing the list of towns", easy_value = 1825, medium_value = 1095, hard_value = 365, custom_value = 1095, flags = 0, min_value = 30, max_value = 1825});
    AddSetting({name = "daylength_ticks", description = "Ticks per ingame day", easy_value = 18, medium_value = 18, hard_value = 18, custom_value = 18, flags = 0, min_value = 18, max_value = 180});
    AddSetting({name = "build_only_zero_price_rvs", description = "Only build zero price RVs", easy_value = 1, medium_value = 1, hard_value = 1, custom_value = 1, flags = AICONFIG_BOOLEAN});
    AddSetting({name = "build_only_zero_running_cost_rvs", description = "Only build zero running cost RVs", easy_value = 0, medium_value = 0, hard_value = 0, custom_value = 0, flags = AICONFIG_BOOLEAN});
    AddSetting({name = "build_only_zero_capacity_rvs", description = "Only build zero capacity RVs", easy_value = 0, medium_value = 0, hard_value = 0, custom_value = 0, flags = AICONFIG_BOOLEAN});
    AddSetting({name = "build_only_if_cargo_type_is_pax", description = "Only build RVs that carry PAX", easy_value = 0, medium_value = 0, hard_value = 0, custom_value = 0, flags = AICONFIG_BOOLEAN});
    AddSetting({name = "debug_signs", description = "Enable building debug signs", easy_value = 0, medium_value = 0, hard_value = 0, custom_value = 0, flags = AICONFIG_BOOLEAN});
  } // GetSettings

} // StreetTraffic2

RegisterAI(StreetTraffic2()); // Tell the core we are an AI
